@@ -48,7 +48,7 @@ for (item in 1:nitems) {
     parms <- model.fit$coefficients[1:(2*nless)]
 
 # --- maximum of log pseudo-likelihood function
-    mlpl.item <- as.numeric(model.fit$logLik)
+    mlpl.item <- as.numeric(model.fit$logLik[1])
 
   	item.log[[item]] <- rbind(item.log[[item]],
 	                          c(item, mlpl.item, parms))
