@@ -90,7 +90,7 @@ FitStack <- function(Master, item.log, phi.log, fstack, TraitByTrait, pq.mat,
 
   # --- Prepare output
   parms <- model.fit$coefficients[1:(nitems*nless + Maxnphi)]
-  logLike <- as.numeric(model.fit$logLik)
+  logLike <- as.numeric(model.fit$logLik[1])
   phi.log <- rbind(phi.log, c(logLike, parms))
 
    #--- matrix of phi parameters
