@@ -223,7 +223,7 @@ fit.gpcm <- function(Master, Phi.mat, PersonByItem, TraitByTrait, item.by.trait,
 
   # --- Max of ple function to items and phi ---
 	mlpl.item <- sum(estimates[, 1])
-	mlpl.phi  <- as.numeric(phi.mlogit$logLik)
+	mlpl.phi  <- as.numeric(phi.mlogit$logLik[1])
 
   # --- Information criteria for pseudo-likelihood
     nparm <- nless*nitems + nitems + Maxnphi- ntraits
