@@ -54,7 +54,7 @@ fit.independence <- function(Master, LambdaNames, LambdaName, ItemNames) {
     colnames(estimates) <- c("lam1", LambdaName)
 
   # --- maximum of log pseudo-likelihood function
-  mlpl.phi <- as.numeric(fit.stack$logLik)
+  mlpl.phi <- as.numeric(fit.stack$logLik[1])
 
   # --- AIC
   AIC <- -1*mlpl.phi - length(LambdaNames)
