@@ -234,10 +234,10 @@ fit.nominal <- function(Master, Phi.mat, starting.sv, pq.mat, tol,
 
 	# --- Max of ple function to items and phi
 	mlpl.item <- sum(estimates[, 1])
-	mlpl.phi  <- phi.mlogit$logLik
+	mlpl.phi  <- phi.mlogit$logLik[1]
 
 	#--- Information criteria
-    nparm <- 2*nless*nitems + Maxnphi- ntraits
+  nparm <- 2*nless*nitems + Maxnphi- ntraits
 	AIC <- -1*mlpl.item - nparm
 	BIC <- -2*mlpl.item - nparm*log(length(unique(Master$PersonID)))
 
