@@ -7,7 +7,7 @@
 #' zero, and sum of squares equal 1. Scores can be set by user by
 #' specifying them in the item by category matrix of 'starting.sv'.  The
 #' pseudo-likelihood algorithm only runs a single stacked regression.
-#' This functionis called from' ple.lma' but can also be run outside
+#' This function is called from' ple.lma' but can also be run outside
 #' of the main wrapper function.
 #'
 #' @param	 Master        Master data set in long format
@@ -137,7 +137,7 @@ fit.rasch <- function(Master, npersons, nitems, ncat, nless, Maxnphi, pq.mat,
 }
 
   # --- maximum of log pseudo-likelihood function
-  mlpl.phi <- as.numeric(phi.mlogit$logLik)
+  mlpl.phi <- as.numeric(phi.mlogit$logLik[1])
 
   # --- Information criteria for pseudo-likelihood
   nparm <- nless*nitems +  Maxnphi
